summaryrefslogtreecommitdiffstats
path: root/kaddressbook/thumbnailcreator
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/thumbnailcreator')
-rw-r--r--kaddressbook/thumbnailcreator/Makefile.am2
-rw-r--r--kaddressbook/thumbnailcreator/ldifvcardcreator.cpp18
2 files changed, 10 insertions, 10 deletions
diff --git a/kaddressbook/thumbnailcreator/Makefile.am b/kaddressbook/thumbnailcreator/Makefile.am
index 2f8ba9c8..06b763c0 100644
--- a/kaddressbook/thumbnailcreator/Makefile.am
+++ b/kaddressbook/thumbnailcreator/Makefile.am
@@ -5,7 +5,7 @@ kde_module_LTLIBRARIES = ldifvcardthumbnail.la
ldifvcardthumbnail_la_SOURCES = ldifvcardcreator.cpp
ldifvcardthumbnail_la_LDFLAGS = -module $(KDE_PLUGIN) $(KDE_RPATH) $(all_libraries) -no-undefined
-ldifvcardthumbnail_la_LIBADD = $(LIB_TDECORE) $(LIB_KABC) -ltdefx
+ldifvcardthumbnail_la_LIBADD = $(LIB_TDECORE) $(LIB_TDEABC) -ltdefx
noinst_HEADERS = ldifvcardcreator.h
diff --git a/kaddressbook/thumbnailcreator/ldifvcardcreator.cpp b/kaddressbook/thumbnailcreator/ldifvcardcreator.cpp
index a0c557d1..44e4684f 100644
--- a/kaddressbook/thumbnailcreator/ldifvcardcreator.cpp
+++ b/kaddressbook/thumbnailcreator/ldifvcardcreator.cpp
@@ -84,10 +84,10 @@ bool VCard_LDIFCreator::readContents( const TQString &path )
#endif
file.close();
- // convert the file contents to a KABC::Addressee address
- KABC::AddresseeList addrList;
- KABC::Addressee addr;
- KABC::VCardConverter converter;
+ // convert the file contents to a TDEABC::Addressee address
+ TDEABC::AddresseeList addrList;
+ TDEABC::Addressee addr;
+ TDEABC::VCardConverter converter;
#if defined(KABC_VCARD_ENCODING_FIX)
addrList = converter.parseVCardsRaw( contentsRaw );
@@ -95,7 +95,7 @@ bool VCard_LDIFCreator::readContents( const TQString &path )
addrList = converter.parseVCards( contents );
#endif
if ( addrList.count() == 0 )
- if ( !KABC::LDIFConverter::LDIFToAddressee( contents, addrList ) )
+ if ( !TDEABC::LDIFConverter::LDIFToAddressee( contents, addrList ) )
return false;
if ( addrList.count()>1 ) {
// create an overview (list of all names)
@@ -126,7 +126,7 @@ bool VCard_LDIFCreator::readContents( const TQString &path )
name = name.simplifyWhiteSpace();
- KABC::PhoneNumber::List pnList = addr.phoneNumbers();
+ TDEABC::PhoneNumber::List pnList = addr.phoneNumbers();
TQStringList phoneNumbers;
for (unsigned int no=0; no<pnList.count(); ++no) {
TQString pn = pnList[no].number().simplifyWhiteSpace();
@@ -141,11 +141,11 @@ bool VCard_LDIFCreator::readContents( const TQString &path )
text += info + "\n";
// get an address
- KABC::Address address = addr.address(KABC::Address::Work);
+ TDEABC::Address address = addr.address(TDEABC::Address::Work);
if (address.isEmpty())
- address = addr.address(KABC::Address::Home);
+ address = addr.address(TDEABC::Address::Home);
if (address.isEmpty())
- address = addr.address(KABC::Address::Pref);
+ address = addr.address(TDEABC::Address::Pref);
info = address.formattedAddress();
if ( !info.isEmpty() )
text += info + "\n";